.. SPDX-FileCopyrightText: 2022 geisserml <geisserml@gmail.com>
.. SPDX-License-Identifier: CC-BY-4.0

==========
Python API
==========


Version
=======
.. automodule:: pypdfium2._version


Object oriented API
===================
.. automodule:: pypdfium2._helpers.classes


Functional API
==============

Opener/Closer
*************
.. automodule:: pypdfium2._helpers.opener

Saver
*****
.. automodule:: pypdfium2._helpers.saver

Page Renderer
*************
.. automodule:: pypdfium2._helpers.page_renderer

Document Renderer
*****************
.. automodule:: pypdfium2._helpers.pdf_renderer

Text Inserter
*************
.. automodule:: pypdfium2._helpers.text_inserter

TOC Parser
**********
.. automodule:: pypdfium2._helpers.toc

PDF Boxes
*********
.. automodule:: pypdfium2._helpers.boxes

Utilities
*********
.. automodule:: pypdfium2._helpers.utilities

Error Handler
*************
.. automodule:: pypdfium2._helpers.error_handler


Constants
=========

.. automodule:: pypdfium2._helpers.constants
